Package: @PKGNAME@
Title: Orthology mapping package
Description: Orthology mapping package, based on data from NCBI, using NCBI Gene IDs and Taxonomy IDs.
Version: @PKGVERSION@
Author: @AUTHOR@
Maintainer: @MAINTAINER@
Depends: R (>= 2.7.0), methods, AnnotationDbi (>= @ANNDBIVERSION@)
Suggests: DBI, annotate, RUnit
License: @LIC@
biocViews: OrthologyDb, @BIOCVIEWS@

