Package: @PKGNAME@
Title: @PKGTITLE@
Description: @PKGTITLE@ assembled using data from public repositories
Version: @PKGVERSION@
Encoding: UTF-8
Author: Marc Carlson, Hervé Pagès
Maintainer: @MAINTAINER@
Depends: R (>= 2.7.0), methods, AnnotationDbi (>= @ANNDBIVERSION@)
Suggests: DBI
License: @LIC@
organism: @ORGANISM@
species: @SPECIES@
biocViews: InparanoidDb, @BIOCVIEWS@

