Package: seqnames.db
Title: Chromosome Name translations
Description: Provides translation information for various kinds of chromosome name conventions.
Version: @VERSION@
Encoding: UTF-8
Author: Marc Carlson, Hervé Pagès
Maintainer: Bioconductor Package Maintainer <maintainer@bioconductor.org>
Depends: R (>= 2.15.0), methods, AnnotationDbi (>= @ANNOTATIONDBIVERSION@)
Imports: methods, AnnotationDbi
License: Artistic-2.0
biocViews: AnnotationData

