Package: @PKGNAME@
Title: Genome wide annotation for @SPECIES@
Description: Genome wide annotation for @SPECIES@, primarily based on mapping using Entrez Gene identifiers.
Version: @PKGVERSION@
Author: Roxane Legaie
Maintainer: Roxane Legaie <R.Legaie@warwick.ac.uk>
Depends: R (>= 2.7.0), methods, AnnotationDbi (>= @ANNDBIVERSION@)
Suggests: DBI, annotate, RUnit
License: @LIC@
organism: @ORGANISM@
species: @SPECIES@
biocViews: OrgDb, @BIOCVIEWS@

