Package: AnnotationForge
Title: Tools for building SQLite-based annotation data packages
Description: Provides code for generating Annotation packages and
        their databases.  Packages produced are intended to be
        used with AnnotationDbi.
biocViews: Annotation, Infrastructure
URL: https://bioconductor.org/packages/AnnotationForge
BugReports: https://github.com/Bioconductor/AnnotationForge/issues
Version: 1.55.0
License: Artistic-2.0
Encoding: UTF-8
Authors@R: c(
        person("Marc", "Carlson", role = "aut"),
        person("Hervé", "Pagès", role = "aut"),
        person("Madelyn", "Carlson", role = "ctb",
                comment = "'Creating probe packages' vignette translation from Sweave to Rmarkdown / HTML"),
        person("Bioconductor Package Maintainer", role = "cre",
                email = "maintainer@bioconductor.org")
        )
Depends: R (>= 3.5.0), methods, utils, BiocGenerics (>= 0.15.10),
        Biobase (>= 1.17.0), AnnotationDbi (>= 1.33.14)
Imports: DBI, RSQLite, XML, S4Vectors, RCurl
Suggests: biomaRt, httr, GenomeInfoDb (>= 1.17.1), Biostrings, affy,
        hgu95av2.db, human.db0, org.Hs.eg.db, Homo.sapiens, GO.db,
        rmarkdown, BiocStyle, knitr, BiocManager, BiocFileCache, RUnit
VignetteBuilder: knitr
BuildKeepEmpty: TRUE
Collate: makeAnnDbPkg.R sqlForge_utils.R sqlForge_baseMapBuilder.R
        sqlForge_schemaGen.R sqlForge_tableBuilder.R
        sqlForge_makeAnnPkgs.R sqlForge_wrapBaseDBPkgs.R
        sqlForge_seqnames.R makeProbePackage.R makeOrgPackage.R
        makeChipPackageFromDataFrames.R makeOrgPackageFromNCBI.R
        NCBI_getters.R makeInparanoidDbs.R
        test_AnnotationForge_package.R
Date: 2024-10-28
git_url: https://git.bioconductor.org/packages/AnnotationForge
git_branch: devel
git_last_commit: 2dc6360
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-07-09
NeedsCompilation: no
Packaged: 2026-07-09 20:25:30 UTC; biocbuild
Author: Marc Carlson [aut],
  Hervé Pagès [aut],
  Madelyn Carlson [ctb] ('Creating probe packages' vignette translation
    from Sweave to Rmarkdown / HTML),
  Bioconductor Package Maintainer [cre]
Maintainer: Bioconductor Package Maintainer <maintainer@bioconductor.org>
Built: R 4.6.1; ; 2026-07-10 05:33:33 UTC; unix
