Package: @PKGNAME@
Title: Base Level Annotation databases for @SPECIES@
Description: Base annotation databases for @SPECIES@, intended ONLY to be used by AnnotationDbi to produce regular annotation packages.
Version: @PKGVERSION@
Author: @AUTHOR@
Maintainer: @MAINTAINER@
Depends: R (>= 2.7.0), methods, AnnotationDbi (>= @ANNDBIVERSION@)
License: @LIC@
organism: @ORGANISM@
species: @SPECIES@
biocViews: db0, @BIOCVIEWS@
