Package: @PKGNAME@
Title: @PKGTITLE@
Description: @PKGTITLE@ assembled using data from KEGG
Version: @PKGVERSION@
Author: @AUTHOR@
Maintainer: @MAINTAINER@
Depends: R (>= 2.7.0), methods, AnnotationDbi (>= @ANNDBIVERSION@)
Suggests: DBI
License: file LICENSE
License_restricts_use: yes 
biocViews: @BIOCVIEWS@

