Package: @PKGNAME@
Title: @PKGTITLE@
Description: @PKGTITLE@ assembled using data from public repositories
Version: @PKGVERSION@
Author: @AUTHOR@
Maintainer: @MAINTAINER@
Depends: R (>= 2.7.0), methods, AnnotationDbi (>= @ANNDBIVERSION@), org.At.tair.db (>= @ORGVERSION@)
Suggests: DBI, annotate, RUnit
License: @LIC@
organism: @ORGANISM@
species: @SPECIES@
manufacturer: @MANUF@
chipName: @CHIPNAME@
manufacturerUrl: @MANUFURL@
biocViews: ChipDb, @BIOCVIEWS@
