Package: @PKGNAME@
Title: @PKGTITLE@
Description: @PKGTITLE@ assembled using data from public repositories
Version: @PKGVERSION@
Author: Marc Carlson, Ting-Yuan Liu, ChenWei Lin, Seth Falcon, Jianhua
        Zhang, James W. MacDonald
Maintainer: @MAINTAINER@
Depends: R (>= 2.7.0), methods, AnnotationDbi (>= @ANNDBIVERSION@)
Suggests: DBI
License: @LIC@
manufacturerUrl: @MANUFURL@
biocViews: @BIOCVIEWS@

