import(methods)
import(AnnotationDbi)

### Only put what is statically exported here. All the AnnObj instances
### created at load time are dynamically exported (refer to R/zzz.R for
### the details).
export(
    @ANNOBJPREFIX@_dbconn,
    @ANNOBJPREFIX@_dbfile,
    @ANNOBJPREFIX@_dbschema,
    @ANNOBJPREFIX@_dbInfo
)

