import(methods)
importFrom(utils, available.packages, download.file, installed.packages,
                  packageDescription, read.csv, read.delim, read.table,
                  str, untar, unzip, write.table)
import(Biobase)
import(DBI)
import(RSQLite)
import(BiocGenerics)
import(S4Vectors)
import(AnnotationDbi)
import(XML)
importFrom(RCurl, getURL)

exportClasses(
    ## from R/AnnDbPkg-maker.R
    "AnnDbPkgSeed"
       
)

exportMethods(
    "makeAnnDbPkg"
)

export(
    ## from R/AnnDbPkg-maker.R
    loadAnnDbPkgIndex, makeAnnDbPkg,
       
    ## help functions for making sqlite files
    populateDB, 

    ## wrapper functions for making chip packages
    makeDBPackage,

    available.db0pkgs,
    available.dbschemas, 
    available.chipdbschemas,
 
    #Convenience function to make the intermediate DB pkgs
    wrapBaseDBPackages,

    ## This one will make you an org package:
    makeOrgPackageFromNCBI,

    ## This one will make you an org package from just data.frames:
    makeOrgPackage,
    makeChipPackage,
       
    ## from R/makeProbePackage.R
    getProbeDataAffy,
    getProbeData_1lq,
    makeProbePackage,
    makeInpDb
)
