[<img src="https://www.bioconductor.org/images/logo/jpg/bioconductor_logo_rgb.jpg" width="200" align="right"/>](https://bioconductor.org/)

**AnnotationForge** is an R/Bioconductor package that provides tools for building SQLite-based annotation data packages.

See https://bioconductor.org/packages/AnnotationForge for more information including how to install the release version of the package (please refrain from installing directly from GitHub).

